function yvals = hgeneval(mu,nu,xvals)
%
% function yvals = hgeneval(mu,nu,xvals)
% evaluates a generalized Hermite polynomial at a range of values.
%
% polynomials in r^2 are orthogonal
% with respect to r^(2*mu)*exp(-r^2/2) on the plane or
% with respect to r^(2*mu+1)*exp(-r^2/2) on [0, inf]
% and are monic (leading term=1)
%
% mu and nu may be one-dimensional arrays, if so, they must match in length
%   mu: exponent in the weight function (see above)
%   nu: number of zeros in [0, inf]
% Hermite polynomials are orthogonal with respect to a Gaussian of unit variance
% and are monic (leading term=1)
%
% yvals: resulting values
%    size(yvals,1)=max(length(mu),length(nu))
%    size(yvals,2)=length(xvals)
%
%   See also HERMCGEN.
%
coefs=hermcgen(mu,nu);
yvals=zeros(size(coefs,1),length(xvals));
for np=1:size(coefs,1)
   yvals(np,:)=polyval(fliplr(coefs(np,:)),xvals);
end
return
