function coefs = hermcgen(mu,nu)
%
% function coefs = hermcgen(mu,nu)
% calculates coefficients of generalized Hermite polynomials
%
% polynomials in r^2 are orthogonal
% with weight r^(2*mu)*exp(-r^2/2) on the plane or
% with weight r^(2*mu+1)*exp(-r^2/2) on [0, inf]
% and are monic (leading term, at end of coef array, =1)
%
% mu and nu may be one-dimensional arrays, if so, they must match in length
%
% coefs: array with one row for each element in mu and nu,
% and of max(nu)+1 columns
%    constant term is in the first column
%
% non-recursive calculation
% see bandspac.doc for details
%
%   See also HGENEVAL.
%
if (length(mu) == 1); muvals= repmat(mu,length(nu),1); else muvals=squeeze(mu)'; end
if (length(nu) == 1); nuvals= repmat(nu,length(mu),1); else nuvals=squeeze(nu)'; end
if (length(nuvals)~=length(muvals)); error('length mismatch of arguments'); end
coefs=zeros(length(nu),max(nu)+1);
for ival=1:length(nuvals);
   m=muvals(ival);n=nuvals(ival);
   coefs(ival,1:n+1)=gamma(m+n+1)*gamma(n+1)*(-2).^(n-[0:n])./(gamma(m+1+[0:n]).*gamma(1+[0:n]).*gamma(n+1-[0:n]));
end
return
