function yvals = hermeval(nrange,xvals,coefs)
%
% function yvals = hermeval(nrange,xvals,coefs)
% evaluates a Hermite polynomial at a range of values.
% Hermite polynomials are orthogonal with respect to a Gaussian of unit variance
% and are monic (leading term=1)
%
% nrange: order(s) to calculate
% xvals: arguments of the polynomials
% coefs: if supplied and non-empty, the coefficients
%    as calculated by hermcoef(nrange).  No checking is done.
% yvals: resulting values
%    size(yvals,1)=nrange(2)-nrange(1)+1
%    size(yvals,2)=length(xvals)
%
%   See also HERMCOEF.
%
if (nargin<=2)
   coefs=[];
end
if (isempty(coefs))
	coefs=hermcoef(nrange);
end
yvals=zeros(size(coefs,1),length(xvals));
for np=1:size(coefs,1)
   yvals(np,:)=polyval(fliplr(coefs(np,:)),xvals);
end
return
