%twodh_demo
%
% demonstrates Cartesian and polar Hermite functions
%   Jonathan D. Victor, 2004
%
opts.npts=128;  %number of points on each side of array
opts.xvalmax=8;  %maximum x-value
opts.ranks=[0:7]; %list of ranks; rank n generates n+1 basis functions
opts.nexamples=1; %number of random examples to make
opts.colormaptype='jet'; %color map for plot
opts.plotbasisf=1; % nonzero to plot basis functions
opts.plotrandfunc=0; %  nonzero to plot random functions
opts.nocross=0% nonzero to suppress contributions of "mixed" eigenfunctions with both nx and ny nonzero
%
npxls=opts.npts^2; %number of pixels
nmaps=(max(opts.ranks)+1)*(max(opts.ranks)+2)/2; %number of maps
da=4*opts.xvalmax^2/npxls; %area element
%
disp('making two-dimensional Hermite functions in Cartesian separation')
[randfunc,randwts,tdh_cart,nx,ny,xvals,optsused]=rbcmake(opts);
disp('size of generated array');
disp(size(tdh_cart));
%
disp('making two-dimensional Hermite functions in polar separation')
[randfunc,randwts,tdh_polar,mu,nu,desc,xvals,optsused]=rbpmake(opts);
disp('size of generated array');
disp(size(tdh_polar));
%
disp('demonstrating orthogonality');
cart_cart=reshape(tdh_cart,npxls,nmaps)'*reshape(tdh_cart,npxls,nmaps)*da;
polar_polar=reshape(tdh_polar,npxls,nmaps)'*reshape(tdh_polar,npxls,nmaps)*da;
polar_cart=reshape(tdh_polar,npxls,nmaps)'*reshape(tdh_cart,npxls,nmaps)*da;
figure;
subplot(2,2,2);imagesc(cart_cart,[-1 1]);xlabel('cart'),ylabel('cart');colorbar;
subplot(2,2,3);imagesc(polar_polar,[-1 1]);xlabel('polar'),ylabel('polar');colorbar;
subplot(2,2,1);imagesc(polar_cart,[-1 1]);xlabel('polar'),ylabel('cart');colorbar;
